package com.xy.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xy.dto.DeviceAnnualFeeDto;
import com.xy.entity.DeviceAnnualFee;
import com.xy.mapper.DeviceAnnualFeeMapper;
import com.xy.utils.MercAuthUtils;
import com.xy.utils.MybatisPlusQuery;
import com.xy.utils.PageBean;
import com.xy.utils.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.time.LocalDateTime;

import static com.xy.utils.PlusBeans.toIPage;
import static com.xy.utils.PlusBeans.toPageBean;


/**
 * <p>
 * 设备年费表 服务实现类
 * </p>
 *
 * @author lijin
 * @since 2025-02-28
 */
@Service
@AllArgsConstructor
@Api(tags = "设备年费表")
public class DeviceAnnualFeeServiceImpl extends ServiceImpl<DeviceAnnualFeeMapper, DeviceAnnualFee> implements DeviceAnnualFeeService {

    @PostMapping("check")
    @ApiOperation("检查")
    public R check(@RequestBody DeviceAnnualFeeDto.Check check) {
        long count = count(new LambdaQueryWrapper<DeviceAnnualFee>()
                .eq(DeviceAnnualFee::getDeviceId, check.getDeviceId())
                .ge(DeviceAnnualFee::getTimeout, LocalDateTime.now())
        );
        if (count == 0) {
            return R.fail("已欠费");
        }
        return R.ok();
    }

    @PostMapping("page")
    @ApiOperation("分页查询")
    public R<PageBean<DeviceAnnualFeeDto.Vo>> page(@RequestBody DeviceAnnualFeeDto.Page page) {
        PageBean pageBean = page.getPage();
        LambdaQueryWrapper<DeviceAnnualFee> lambdaQueryWrapper = new MybatisPlusQuery()
                .eqWrapper(page, DeviceAnnualFee.class)
                .ge(DeviceAnnualFee::getTimeout, page.getBeginTime())
                .le(DeviceAnnualFee::getTimeout, page.getEndTime())
                .build();
        IPage<DeviceAnnualFee> iPage = page(toIPage(pageBean), lambdaQueryWrapper);
        return R.ok(toPageBean(DeviceAnnualFeeDto.Vo.class, iPage));
    }

    @PostMapping("mercPage")
    @ApiOperation("商家分页查询")
    public R<PageBean<DeviceAnnualFeeDto.Vo>> mercPage(@RequestBody DeviceAnnualFeeDto.Page page) {
        page.setMercId(MercAuthUtils.getMercId());
        return page(page);
    }

}